//===========================================================================
// [File Name] bst-simple.sc (a simple version)
// [Machine] FNAL-BST
//
//===========================================================================

//=== [MacroParticles to be Injected] ===============
 nMacrosPerTurn     = 1000;
 Integer InjTurns   = 11;
 nMaxMacroParticles = InjTurns*nMacrosPerTurn;
 Real QpBckt        = 6.00e10;
 nReals_Macro       = QpBckt/Real(nMaxMacroParticles);
 
 Real Vrf = 205.0;

 // from MAD lattice:
 Real rhoD = 48.034101;//[m]
 Real rhoF = 40.847086; 

 
//===== [Files for Output] ==========================
  String outF;
  runName = "Booster";
  outF = runName  + ".out";
  OFstream fio( outF, ios::out );


///////////////////////////////////////
//   Make a Synchronous Particle
///////////////////////////////////////

  Real TSync     = 0.400;
  Real mSync     = 1;    
  Integer charge = 1;
  addSyncPart( mSync, charge, TSync );
  mainHerd = addMacroHerd(nMaxMacroParticles);


/////////////////////////
//   Make a Ring 
/////////////////////////

  String twFile = "booster_v11.tw";
  String tmFile = "booster_v11.tm"; 

  readMADFile( twFile, tmFile );
  cerr << "\n\t\t\t * MAD Lattices are read through. \n";

  Ring::lRing          = 474.202753;
  Ring::gammaTrans     = 5.445513;   
  Ring::harmonicNumber = 84;


////////////////////////////////////////////////////////////////
//    Create X, Y, & Z Distribution Initializer Functions
///////////////////////////////////////////////////////////////

  betaXInj = 6.17585; alphaXInj = -0.0939789;

  MXJoho = 100.; 
  Real epsX = 0.874;
  epsXLimInj = epsX * (MXJoho + 1) * 2.0;
  xTailFraction = 0.0; xTailFactor = 3.;
  addXInitializer( "BiGaussX", JohoXDist );



  betaYInj = 20.023; alphaYInj = -0.029;
  MYJoho = 100.; 
  Real epsYrms = 1.76;
  epsYLimInj = epsYrms * (MYJoho + 1) * 2.0;
  y0Inj = 0.0; yP0Inj = 0.0; 
  yTailFraction = 0.0; yTailFactor = 3.;
  addYInitializer( "BiGaussY", JohoYDist );



  phiMinInj = -120.0; phiMaxInj = 120.0;
  EOffset = 0.0;
  deltaEFracInj = 7.47E-4;
  addLongInitializer( "Uniform", UniformLongDist );


////////////////////////////
//    Add a Foil Node
////////////////////////////

  Real foilRho = 369.;//[ug/cm**2]
  addFoil( "Foil", 2, -100.00, 100.00, -100.00, 100.00, foilRho );
  useFoilScattering = 0;


////////////////////////////////////
//     Add a RF Cavity
////////////////////////////////////

  Real tFactor;
  Integer nRFHarms = 1;
  RealVector volts(nRFHarms), harmNum(nRFHarms), RFPhase(nRFHarms);
  harmNum(1) = 1;
  RFPhase(1) = 0.;

  volts(1) = Vrf;
  addRFCavity( "RF(1)", 4, nRFHarms, volts, harmNum, RFPhase );

  
//////////////////////////////////////////////
//   Add a Longitudinal Space-Charge Node
//////////////////////////////////////////////

  ComplexVector ZImped(32);
  ZImped = Complex(0.,0.);

  nLongBins = 8;
  Real b_a  = 2.;
  Integer useAvg = 0;
  Integer nMacroLSCMin   = 1;
  Integer useSpaceCharge = 1;
  addFFTLSpaceCharge( "LSC(1)", 5, ZImped, b_a, useAvg, 
	       	nMacroLSCMin, useSpaceCharge );


////////////////////////////////////////////////
//  Add a Transverse Space-Charge Node Set
////////////////////////////////////////////////

  Integer nxBins = 16, nyBins = 16;
  Real    eps    = 1.e-6;
  Integer nMacroTSCMin = 1;
  addFFTTransSCSet( nxBins, nyBins, eps, nMacroTSCMin );


///////////////////////////////////////////
//     Add Moment and StatLat Nodes
///////////////////////////////////////////
 
  addMomentNode(  "MomentNode(0)",  7, 2, "Moments.out"  );       
  addStatLatNode( "StatLatNode(0)", 8,    "StatLats.out" );       
  activateMomentNode(1);
  activateStatLatNode(1);


/////////////////////////////
//   Overall Ring Info
////////////////////////////
 
  showStart(fio); 
  showFoil(fio);


////////////////////////////////////////////////////////////////
//    Do some turns, and dump particles for post-processing
////////////////////////////////////////////////////////////////

  cerr << "\n\t\t\t * Start Tracking ... \n"; 
  
  doTurn(5);
  
  showTurnInfo(fio); showTurnInfo(cerr);




  deactivateMomentNodes();
  deactivateStatLatNodes();

  fio.close();
  quit

// ====== EoF ==========================================================================
